<?php

namespace Tests\Unit;

use PHPUnit\Framework\TestCase;
use function Evoluted\Deployer\Db\getDatabaseName;
use function Evoluted\Deployer\Db\shortenDatabaseName;

require __DIR__.'/../../recipe/db.php';

class MySqlTest extends TestCase
{
    /**
     * @dataProvider getNameProvider
     */
    public function testGetName(string $project, string $branch, string $application, string $prefix, string $expectedName): void
    {
        $name = getDatabaseName($project, $branch, $application, $prefix, 'mysql');
        $this->assertSame($name, $expectedName);
    }

    public function getNameProvider(): array
    {
        return [
            'empty' => [ '', '' , '', '', '_' ],
            'short, no app, no prefix' => [ 'project', 'branch', '', '', 'project_branch' ],
            'short, no app' => [ 'project', 'branch', '', 'prefix_', 'prefix_project_branch' ],
            'short' => [ 'project', 'branch', 'app', 'prefix_', 'prefix_project_app_branch' ],
            'long' => [
                'decorative_aggregates',
                'feature-collection-orders',
                'colouredquartz',
                'cd_',
                'cd_decorative_aggregates_2su1v2m_feature_collection_orders',
            ],
        ];
    }

    /**
     * @dataProvider shortenDatabaseNameProvider
     */
    public function testShortenDatabaseName(string $inputName, string $project, string $branch, string $prefix, string $expectedOutputName): void
    {
        $name = shortenDatabaseName($inputName, $project, $branch, $prefix, 'mysql');
        $this->assertSame($name, $expectedOutputName);
    }

    public function shortenDatabaseNameProvider(): array
    {
        return [
            'empty' => [ '', '', '', '', '' ],
            'short' => [ 'a', 'b', 'c', 'd', 'a' ],
            'not long enough' => [
                'cd_premier_products_ecommerce_feature_admin_frontend',
                'premier_products_ecommerce',
                'feature-admin-frontend',
                'cd_',
                'cd_premier_products_ecommerce_feature_admin_frontend',
            ],
            'long' => [
                'cd_decorative_aggregates_colouredquartz_feature_collection_orders',
                'decorative_aggregates',
                'feature-collection-orders',
                'cd_',
                'cd_decorative_aggregates_2su1v2m_feature_collection_orders',
            ],
        ];
    }
}